import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Select, Button, Input, Cascader, Tooltip } from 'antd'
import { QuestionCircleOutlined } from '@ant-design/icons'

import ColorSketch from '@/mob/colorsketch'
import './index.scss'

class UniqueForm extends Component {
  static propTpyes = {
    field: PropTypes.any,
    columns: PropTypes.array,       // 列名集合
    signs: PropTypes.array,         // 标记类型
    markChange: PropTypes.func      // 修改函数
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        if (values.contrastValue) {
          values.contrastValue = values.contrastValue.replace(/\t+|\v+|\s+/g, '')
        }
        this.props.markChange(values)
      }
    })
  }

  render() {
    const { columns, signs, field } = this.props
    const { getFieldDecorator } = this.props.form
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    let initVal = []
    if (field) {
      initVal = [field, 'static']
    }

    return (
      <Form {...formItemLayout} className="normal-table-mark-form">
        <Row gutter={24}>
          <Col span={6}>
            <Form.Item label={'对比字段'}>
              {getFieldDecorator('field', {
                initialValue: initVal,
                rules: [
                  {
                    required: true,
                    message: '请选择对比字段!'
                  },
                  {
                    validator: (rule, value, callback) => {
                      if (value[1] === 'dynamic' && value[0] === value[2]) {
                        callback('对比字段不可相同！')
                      } else {
                        callback()
                      }
                    }
                  }
                ]
              })(
                <Cascader className="mark-type" options={columns} placeholder=""/>
              )}
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item label={'对比方式'}>
              {getFieldDecorator('match', {
                initialValue: '=',
                rules: [
                  {
                    required: true,
                    message: '请选择对比方式!'
                  }
                ]
              })(
                <Select>
                  <Select.Option value="="> = </Select.Option>
                  <Select.Option value="!="> != </Select.Option>
                  <Select.Option value=">"> &gt; </Select.Option>
                  <Select.Option value="<"> &lt; </Select.Option>
                  <Select.Option value="like"> like </Select.Option>
                </Select>
              )}
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item label={<Tooltip placement="topLeft" title="对比静态值时，需要填写对比值，默认为空。">
              <QuestionCircleOutlined className="mk-form-tip" />
                {'对比值'}
              </Tooltip>
            }>
              {getFieldDecorator('contrastValue', {
                initialValue: ''
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item label="颜色">
              {getFieldDecorator('color', {
                initialValue: 'rgba(0, 0, 0, 0.85)',
                rules: [
                  {
                    required: true,
                    message: '请选择颜色!'
                  }
                ]
              })(
                <ColorSketch />
              )}
            </Form.Item>
          </Col>
          {signs.length ? <Col span={6}>
            <Form.Item label="标记方式">
              {getFieldDecorator('signType', {
                initialValue: [],
                rules: [
                  {
                    required: true,
                    message: '请选择标记方式!'
                  }
                ]
              })(
                <Cascader popupClassName="mark-type" options={signs} placeholder=""/>
              )}
            </Form.Item>
          </Col> : null}
          <Col span={signs.length ? 18 : 24} style={{textAlign: 'right'}}>
            <Button onClick={this.handleConfirm} type="primary" className="mk-green">
              添加
            </Button>
          </Col>
        </Row>
      </Form>
    )
  }
}

export default Form.create()(UniqueForm)